@@ -10,8 +10,11 @@ URL     = "https://dronebl.org/RPC2"
 HEADERS = {"Content-Type": "text/xml"}
 
 class BaseDroneBL(object):
-    def __init__(self, key: str):
-        self._key = key.encode("ascii")
+    def __init__(self,
+            key:     str,
+            timeout: float = 10.0):
+        self._key     = key.encode("ascii")
+        self._timeout = timeout
 
     def batch(self) -> make.Batch:
         return make.Batch()
@@ -24,7 +27,7 @@ class DroneBL(BaseDroneBL):
             ) -> bytes:
         data     = make.request(self._key, method)
         request  = urllib.request.Request(URL, data, HEADERS, method="POST")
-        response = urllib.request.urlopen(request, timeout=5)
+        response = urllib.request.urlopen(request, timeout=self._timeout)
         return response.read()
 
     def lookup(self,
@@ -46,6 +49,14 @@ class DroneBL(BaseDroneBL):
         responses = self._post(method)
         return parse.add(responses)
 
+    def update(self,
+            id:      int,
+            comment: str
+            ) -> Tuple[bool, str]:
+        method    = make.update(id, comment)
+        responses = self._post(method)
+        return parse.update(responses)
+
     def remove(self,
             id: int
             ) -> Tuple[bool, str]:
@@ -69,7 +80,7 @@ class AsyncDroneBL(BaseDroneBL):
         data = make.request(self._key, method)
         async with AsyncClient() as client:
             response = await client.post(
-                URL, data=data, headers=HEADERS, timeout=5
+                URL, data=data, headers=HEADERS, timeout=self._timeout
             )
         return response.content
 
@@ -92,6 +103,14 @@ class AsyncDroneBL(BaseDroneBL):
         responses = await self._post(method)
         return parse.add(responses)
 
+    async def update(self,
+            id:      int,
+            comment: str
+            ) -> Tuple[bool, str]:
+        method    = make.update(id, comment)
+        responses = await self._post(method)
+        return parse.update(responses)
+
     async def remove(self,
             id: int
             ) -> Tuple[bool, str]:
